@@ -4,10 +4,25 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-2015 Gerd Neugebauer
+** (c) 1996-2016 Gerd Neugebauer
 ** 
 ** Net: gene@gerd-neugebauer.de
 ** 
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2, or (at your option)
+** any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+**
+**-----------------------------------------------------------------------------
 ** >>> See the file doc/c_lib.tex for a printed documentation of the
 ** >>> main parts of the C source.
 ** 
@@ -155,7 +170,7 @@ char * getenv(name)				   /*			     */
     "\t%c$\t\tSymbol table output (debugging only)\n",
 #endif
     0L,
-    "Copyright (C) 2014 Gerd Neugebauer",
+    "Copyright (C) 2016 Gerd Neugebauer",
     "gene@gerd-neugebauer.de"
   };
 
@@ -259,17 +274,17 @@ static void usage(fullp)			   /*			     */
 void save_input_file(file)			   /*			     */
   char *file;					   /*			     */
 {						   /*			     */
-  if ( file == NULL )				   /*			     */
+  if (file == NULL)				   /*			     */
   { WARNING("Missing input file name. Flag ignored.");/*		     */
     return;					   /*			     */
   }						   /*			     */
-  if ( *file == '-' && file[1] == '\0' )	   /*			     */
+  if (*file == '-' && file[1] == '\0')		   /*			     */
   { file = NULL; }				   /*			     */
 						   /*			     */
-  if ( InputPipeIsFull )			   /* No space left?	     */
+  if (InputPipeIsFull)				   /* No space left?	     */
   { input_file_size += InputFilePipeIncrement;	   /*			     */
 						   /*			     */
-    if ( InputPipeIsEmpty			   /* Try to enlarge array   */
+    if (InputPipeIsEmpty			   /* Try to enlarge array   */
 	? NULL==(input_files=			   /*			     */
 		 (char**)malloc(sizeof(char*)	   /*			     */
 				*(size_t)input_file_size))/*		     */
@@ -278,8 +293,7 @@ void save_input_file(file)			   /*			     */
 				 sizeof(char*)	   /*			     */
 				 *(size_t)input_file_size))/*		     */
 	)					   /*			     */
-    { OUT_OF_MEMORY("input file pipe.");	   /*		             */
-    }						   /*			     */
+    { OUT_OF_MEMORY("input file pipe."); }	   /*			     */
   }						   /*			     */
   PushToInputPipe(file);			   /*			     */
 }						   /*------------------------*/
@@ -337,20 +351,19 @@ void save_macro_file(file)			   /*			     */
 /*-----------------------------------------------------------------------------
 ** Function:	keep_selected()
 ** Type:	static int
-** Purpose:	
+** Purpose:	Mark the record as deleted if it is not selected.
 **		
 ** Arguments:
-**	db	
-**	rec	
-** Returns:	
+**	db	the database
+**	rec	the record
+** Returns:	FALSE
 **___________________________________________________			     */
-static int keep_selected(db,rec)		   /*                        */
+static int keep_selected(db, rec)		   /*                        */
   DB db;					   /*                        */
   Record rec;					   /*                        */
 {						   /*                        */
-  if ( !is_selected(db,rec) )			   /*                        */
-  { SetRecordDELETED(rec);			   /*                        */
-  }						   /*                        */
+  if (!is_selected(db, rec))			   /*                        */
+  { SetRecordDELETED(rec); }			   /*                        */
  						   /*                        */
   return FALSE;					   /*                        */
 }						   /*------------------------*/
@@ -362,9 +375,9 @@ static int keep_selected(db,rec)		   /*                        */
 ** Purpose:	Undelete crossreferenced entries
 **		
 ** Arguments:
-**	db	
-**	rec	
-** Returns:	
+**	db	the database
+**	rec	the record
+** Returns:	FALSE
 **___________________________________________________			     */
 int keep_xref(db,rec)				   /*                        */
   DB db;					   /*                        */
@@ -374,9 +387,9 @@ int keep_xref(db,rec)				   /*                        */
   { String key;				   	   /*                        */
     int    count;				   /*                        */
  						   /*                        */
-    for ( count = rsc_xref_limit;		   /* Prevent infinite loop  */
-	  count >= 0;		   	   	   /*                        */
-	  count-- )				   /*                        */
+    for (count = rsc_xref_limit;		   /* Prevent infinite loop  */
+	 count >= 0;		   	   	   /*                        */
+	 count--)				   /*                        */
     {					   	   /*                        */
       if ( (key = get_field(db,rec,sym_crossref)) == NULL )/*                */
       { return FALSE; }			   	   /*                        */
@@ -390,7 +403,7 @@ int keep_xref(db,rec)				   /*                        */
         return FALSE;			   	   /*                        */
       }					   	   /*                        */
  						   /*                        */
-      if ( !RecordIsDELETED(rec) ) { return FALSE; }/*                       */
+      if (!RecordIsDELETED(rec)) { return FALSE; } /*                        */
       ClearRecordDELETED(rec);		   	   /*                        */
     }					   	   /*                        */
  						   /*                        */
@@ -401,7 +414,6 @@ int keep_xref(db,rec)				   /*                        */
 }						   /*------------------------*/
 #endif
 
-
 #define Toggle(X) X = !(X)
 
 /*-----------------------------------------------------------------------------
@@ -524,9 +536,8 @@ int main(argc,argv)				   /*			     */
  						   /*  has been modified.    */
   the_db = new_db();				   /*                        */
 						   /*			     */
-  for ( i = 0; i < input_file_ptr; i++ )	   /* For all input files    */
-  {						   /*			     */
-    if ( read_db(the_db,			   /*                        */
+  for (i = 0; i < input_file_ptr; i++)		   /* For all input files    */
+  { if ( read_db(the_db,			   /*                        */
 		 (String)(input_files[i]),	   /*                        */
 		 rsc_verbose) )	   		   /*                        */
     { NoFileError(input_files[i]); }		   /*			     */
@@ -645,7 +656,7 @@ int main(argc,argv)				   /*			     */
 		   cnt[i]);		   	   /*			     */
       }						   /*			     */
     }						   /*			     */
-    free(c);
+    free(c);					   /*                        */
   }						   /*                        */
 						   /*			     */
 #ifdef SYMBOL_DUMP
@@ -673,7 +684,7 @@ int main(argc,argv)				   /*			     */
 **	r2
 ** Returns:	
 **___________________________________________________			     */
-static int rec_gt(r1,r2)			   /*                        */
+static int rec_gt(r1, r2)			   /*                        */
   Record r1;					   /*                        */
   Record r2;					   /*                        */
 { return (strcmp((char*)RecordSortkey(r1),	   /*                        */
@@ -690,7 +701,7 @@ static int rec_gt(r1,r2)			   /*                        */
 **	r2
 ** Returns:	
 **___________________________________________________			     */
-static int rec_lt(r1,r2)			   /*                        */
+static int rec_lt(r1, r2)			   /*                        */
   Record r1;					   /*                        */
   Record r2;					   /*                        */
 { return (strcmp((char*)RecordSortkey(r1),	   /*                        */
@@ -707,7 +718,7 @@ static int rec_lt(r1,r2)			   /*                        */
 **	r2	
 ** Returns:	
 **___________________________________________________			     */
-static int rec_gt_cased(r1,r2)			   /*                        */
+static int rec_gt_cased(r1, r2)			   /*                        */
   Record r1;					   /*                        */
   Record r2;					   /*                        */
 { return (strcmp((char*)get_key_name(RecordSortkey(r1)),/*                   */
@@ -724,7 +735,7 @@ static int rec_gt_cased(r1,r2)			   /*                        */
 **	r2	
 ** Returns:	
 **___________________________________________________			     */
-static int rec_lt_cased(r1,r2)			   /*                        */
+static int rec_lt_cased(r1, r2)			   /*                        */
   Record r1;					   /*                        */
   Record r2;					   /*                        */
 { return (strcmp((char*)get_key_name(RecordSortkey(r1)),/*                   */
@@ -740,7 +751,7 @@ static int rec_lt_cased(r1,r2)			   /*                        */
 **	rec
 ** Returns:	
 **___________________________________________________			     */
-static int do_keys(db,rec)			   /*                        */
+static int do_keys(db, rec)			   /*                        */
   DB	 db;					   /*                        */
   Record rec;					   /*                        */
 {						   /*                        */
@@ -761,7 +772,7 @@ static int do_keys(db,rec)			   /*                        */
 **	rec
 ** Returns:	
 **___________________________________________________			     */
-static int do_no_keys(db,rec)			   /*                        */
+static int do_no_keys(db, rec)			   /*                        */
   DB	 db;					   /*                        */
   Record rec;					   /*                        */
 {						   /*                        */
@@ -783,7 +794,7 @@ static int do_no_keys(db,rec)			   /*                        */
 **	first_rec
 ** Returns:	nothing
 **___________________________________________________			     */
-static int update_crossref(db,rec)		   /*			     */
+static int update_crossref(db, rec)		   /*			     */
   DB		 db;				   /*                        */
   Record	 rec;				   /*			     */
 { register String *hp;				   /*			     */
@@ -792,9 +803,9 @@ static int update_crossref(db,rec)		   /*			     */
 						   /*			     */
   if ( !RecordIsXREF(rec) ) return 0;		   /*			     */
 						   /*                        */
-  for ( i = RecordFree(rec), hp = RecordHeap(rec); /* search crossref field  */
-	i > 0 && *hp != sym_crossref;		   /*			     */
-	i -= 2, hp += 2 )			   /*			     */
+  for (i = RecordFree(rec), hp = RecordHeap(rec);  /* search crossref field  */
+       i > 0 && *hp != sym_crossref;		   /*			     */
+       i -= 2, hp += 2)				   /*			     */
   { }						   /*			     */
   if ( i <= 0 )					   /*			     */
   { DebugPrint1("*** No crossref found.");	   /*			     */
@@ -820,7 +831,6 @@ static int update_crossref(db,rec)		   /*			     */
   return 0;					   /*                        */
 }						   /*------------------------*/
 
-
 #define equal_records(R1,R2) RecordSortkey(R1) == RecordSortkey(R2)
 
 /*-----------------------------------------------------------------------------
@@ -832,7 +842,7 @@ static int update_crossref(db,rec)		   /*			     */
 **	rec
 ** Returns:	
 **___________________________________________________			     */
-static int dbl_check(db,rec)			   /*                        */
+static int dbl_check(db, rec)			   /*                        */
   DB	 db;					   /*                        */
   Record rec;					   /*                        */
 {						   /*                        */
