@@ -4,10 +4,24 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-2015 Gerd Neugebauer
+** (c) 1996-2016 Gerd Neugebauer
 ** 
 ** Net: gene@gerd-neugebauer.de
 **	    
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2, or (at your option)
+** any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+**
 ** 
 ** Purpose: Simulate the TeX reading mechanism.
 **
@@ -80,14 +94,14 @@
  static Token TeX_get_token _ARG((int (*get_fct)_ARG((void))));/* tex_read.c */
  static Token new_token _ARG((int type,String string));/* tex_read.c         */
  static Token token_list_copy _ARG((Token t,Token nt,Token *argp));/* tex_read.c*/
- static Token tokenize _ARG((unsigned char *s,int arity));/* tex_read.c      */
+ static Token tokenize _ARG((String s,int arity)); /* tex_read.c             */
  static int TeX_fill_line _ARG((int (*get_fct)_ARG((void))));/* tex_read.c   */
  static int do_get _ARG((void));		   /* tex_read.c             */
  static int fill_token _ARG((Token*tp));	   /* tex_read.c             */
  static int get_EOF _ARG((void));		   /* tex_read.c             */
  static int get_file _ARG((void));		   /* tex_read.c             */
  static int get_string _ARG((void));		   /* tex_read.c             */
- static unsigned char * tokens_to_string _ARG((Token t));/* tex_read.c       */
+ static String tokens_to_string _ARG((Token t));   /* tex_read.c             */
  static void free_1_token _ARG((Token t));	   /* tex_read.c             */
  static void free_macdef _ARG((MacDef mac));	   /* tex_read.c             */
  static void free_tokens _ARG((Token t));	   /* tex_read.c             */
@@ -98,7 +112,7 @@
  void TeX_def _ARG((String s));		   	   /* tex_read.c             */
  void TeX_define _ARG((String name,int arity,String body));/* tex_read.c     */
  void TeX_open_file _ARG((FILE * file));	   /* tex_read.c             */
- void TeX_open_string _ARG((unsigned char * s));   /* tex_read.c             */
+ void TeX_open_string _ARG((String s));		   /* tex_read.c             */
  void TeX_reset _ARG((void));			   /* tex_read.c             */
 
 #ifdef STANDALONE
@@ -315,25 +329,25 @@ static void free_tokens(t)			   /*			     */
 **	t
 ** Returns:	
 **___________________________________________________			     */
-static unsigned char * tokens_to_string(t)	   /*			     */
-  Token			 t;			   /*			     */
-{ register Token	 t1;			   /*			     */
-  register unsigned char *s,			   /*			     */
-			 *sp;			   /*			     */
-  register int		 len;			   /*			     */
+static String tokens_to_string(t)		   /*			     */
+  Token		  t;				   /*			     */
+{ register Token  t1;				   /*			     */
+  register String s,				   /*			     */
+		  sp;				   /*			     */
+  register int	  len;				   /*			     */
 						   /*			     */
-  for ( len=1,t1=t;				   /* Count the elements of  */
-	t1!=TokenNULL;				   /*  the token list.	     */
-	t1=NextToken(t1) )			   /*  (+1 for '\0')	     */
+  for (len = 1, t1 = t;				   /* Count the elements of  */
+       t1 != TokenNULL;				   /*  the token list.	     */
+       t1 = NextToken(t1))			   /*  (+1 for '\0')	     */
   { ++len; }					   /*			     */
 						   /*			     */
-  if ( (s=(unsigned char*)malloc(len*sizeof(unsigned char)))/*               */
+  if ( (s=(String)malloc(len * sizeof(Uchar)))     /*                        */
        == NULL )	   			   /* Try to get             */
   { OUT_OF_MEMORY("TeX string."); } 		   /*     new memory.	     */
 						   /*			     */
-  for ( sp=s,t1=t;				   /* Transfer the characters*/
-	t1!=TokenNULL;				   /*  from the token list   */
-	t1=NextToken(t1) )			   /*  to the string.	     */
+  for (sp = s, t1 = t;				   /* Transfer the characters*/
+       t1 != TokenNULL;				   /*  from the token list   */
+       t1 = NextToken(t1))			   /*  to the string.	     */
   { *(sp++) = TokenChar(t1); }			   /*			     */
   *sp = '\0';					   /*			     */
   return s;					   /* Return the string.     */
@@ -397,7 +411,7 @@ static int TeX_fill_line(get_fct)		   /*			     */
       { NextToken(*tp) = NextToken(NextToken(t));  /*			     */
 	free_1_token(NextToken(t));		   /*			     */
 	free_1_token(t);			   /*			     */
-	TokenChar(*tp) = (c>=64?c-64:c+64);	   /*			     */
+	TokenChar(*tp) = (c >= 64 ? c - 64 : c + 64);/*			     */
       }						   /*			     */
     }						   /*			     */
   }						   /*			     */
@@ -481,8 +495,8 @@ static Token TeX_get_token(get_fct)		   /*			     */
   }						   /*			     */
 }						   /*------------------------*/
 
- static unsigned char *g_s;
- static unsigned char *g_p;
+ static String g_s;				   /*			     */
+ static String g_p;				   /*			     */
 
 /*-----------------------------------------------------------------------------
 ** Function:	init_get()
@@ -494,7 +508,7 @@ static Token TeX_get_token(get_fct)		   /*			     */
 ** Returns:	nothing
 **___________________________________________________			     */
 static void init_get(s)				   /*			     */
-  register unsigned char * s;			   /*			     */
+  register String s;				   /*			     */
 { g_p = g_s = s;				   /*			     */
 }						   /*------------------------*/
 
@@ -521,13 +535,13 @@ static int do_get()				   /*			     */
 **	arity
 ** Returns:	
 **___________________________________________________			     */
-static Token tokenize(s,arity)			   /*			     */
-  unsigned char	*s;				   /*			     */
-  int		arity;				   /*			     */
-{ Token		t = TokenNULL,			   /*			     */
-		t_ret = TokenNULL,		   /*			     */
-		nt, t0;				   /*			     */
-  int		a;				   /*			     */
+static Token tokenize(s, arity)			   /*			     */
+  String s;					   /*			     */
+  int	 arity;					   /*			     */
+{ Token	 t = TokenNULL,				   /*			     */
+	 t_ret = TokenNULL,			   /*			     */
+	 nt, t0;				   /*			     */
+  int	 a;					   /*			     */
 						   /*			     */
   EnsureInit;					   /*			     */
   init_get(s);					   /*			     */
@@ -747,9 +761,9 @@ static int get_EOF()				   /*			     */
 { return EOF;					   /*			     */
 }						   /*------------------------*/
 
- static FILE *src_file;				   /*			     */
- static unsigned char *src_string;		   /*			     */
- static unsigned char *src_ptr;			   /*			     */
+ static FILE  *src_file;			   /*			     */
+ static String src_string;			   /*			     */
+ static String src_ptr;				   /*			     */
  static int  (*src_get)() = get_EOF;		   /*			     */
 
 /*-----------------------------------------------------------------------------
@@ -800,7 +814,7 @@ void TeX_open_file(file)			   /*			     */
 ** Returns:	nothing
 **___________________________________________________			     */
 void TeX_open_string(s)				   /*			     */
-  unsigned char * s;				   /*			     */
+  String s;					   /*			     */
 { src_ptr = src_string = s;			   /*			     */
   src_get = get_string;				   /*			     */
   tex_clear;					   /*			     */
@@ -852,13 +866,13 @@ static int fill_token(tp)			   /*			     */
 ** Returns:	|FALSE| iff everything went right.
 **___________________________________________________			     */
 int TeX_read(cp, sp)				   /*			     */
-  Uchar	 	*cp;				   /*			     */
+  String	cp;				   /*			     */
   String	*sp;				   /*			     */
 { static Token	t     = TokenNULL;		   /*			     */
   static Token	old_t = TokenNULL;		   /*			     */
   static Token	arg[10];			   /*			     */
-  Token		t2,tp;				   /*			     */
-  int		i,d;				   /*			     */
+  Token		t2, tp;				   /*			     */
+  int		i, d;				   /*			     */
 						   /*			     */
   EnsureInit;					   /*			     */
   if ( old_t != TokenNULL ) free_1_token(old_t);   /*			     */
@@ -884,13 +898,13 @@ int TeX_read(cp, sp)				   /*			     */
       return 1;					   /*			     */
     }						   /*			     */
 						   /*			     */
-    for ( i = 1; i <= MacroArity(mac); ++i )	   /* Fill the argument	     */
+    for (i = 1; i <= MacroArity(mac); ++i)	   /* Fill the argument	     */
     {						   /*  vector		     */
       if ( !fill_token(&t) )			   /*			     */
       { arg[i] = TokenNULL;			   /* Not enough tokens	     */
         Err("*** Unexpected EOF\n");		   /*			     */
       }					   	   /*			     */
-      else if ( TokenChar(t) == CHAR_BEG_GROUP )   /* If there is a group    */
+      else if (TokenChar(t) == CHAR_BEG_GROUP)     /* If there is a group    */
       { tp = t;				   	   /*			     */
         d  = 0;				   	   /*			     */
 	while ( fill_token(&NextToken(tp))  &&     /* While there are more   */
@@ -919,7 +933,7 @@ int TeX_read(cp, sp)				   /*			     */
 						   /*			     */
     t = token_list_copy(MacroToken(mac),t,arg);    /*			     */
 						   /*			     */
-    for ( i=1; i<MacroArity(mac); ++i )	   	   /* free the arg vector    */
+    for (i = 1; i < MacroArity(mac); ++i)   	   /* free the arg vector    */
     { if ( arg[i] != TokenNULL )		   /*			     */
       { free_tokens(arg[i]);			   /*			     */
         arg[i] = TokenNULL;			   /*			     */
